@@ -1,13 +1,12 @@
 import pytest
-import os
 import numpy as np
 import glob
 import xarray as xr
+import pandas as pd
 
 import act
 import act.io.armfiles as arm
 import act.tests.sample_files as sample_files
-import act.corrections.ceil as ceil
 from act.plotting import TimeSeriesDisplay, WindRoseDisplay
 from act.plotting import SkewTDisplay, XSectionDisplay
 from act.plotting import GeographicPlotDisplay, HistogramDisplay
@@ -50,6 +49,61 @@ def test_plot():
     return display.fig
 
 
+def test_errors():
+    files = sample_files.EXAMPLE_MET_WILDCARD
+    obj = arm.read_netcdf(files)
+
+    del obj.attrs['_file_dates']
+
+    data = np.empty(len(obj['time'])) * np.nan
+    lat = obj['lat'].values
+    lon = obj['lon'].values
+    obj['lat'].values = data
+    obj['lon'].values = data
+
+    display = TimeSeriesDisplay(obj)
+    display.plot('temp_mean')
+    display.set_yrng([0, 0])
+    with np.testing.assert_warns(RuntimeWarning):
+        display.day_night_background()
+    obj['lat'].values = lat
+    with np.testing.assert_warns(RuntimeWarning):
+        display.day_night_background()
+    obj['lon'].values = lon * 100.
+    with np.testing.assert_warns(RuntimeWarning):
+        display.day_night_background()
+    obj['lat'].values = lat * 100.
+    with np.testing.assert_warns(RuntimeWarning):
+        display.day_night_background()
+
+    obj.close()
+
+    # Test some of the other errors
+    obj = arm.read_netcdf(files)
+    del obj['temp_mean'].attrs['units']
+    display = TimeSeriesDisplay(obj)
+    display.axes = None
+    with np.testing.assert_raises(RuntimeError):
+        display.set_yrng([0, 10])
+    with np.testing.assert_raises(RuntimeError):
+        display.set_xrng([0, 10])
+    display.fig = None
+    display.plot('temp_mean', add_nan=True)
+
+    assert display.fig is not None
+    assert display.axes is not None
+
+    with np.testing.assert_raises(AttributeError):
+        display = TimeSeriesDisplay([])
+
+    fig, ax = matplotlib.pyplot.subplots()
+    display = TimeSeriesDisplay(obj)
+    display.add_subplots((2, 2), figsize=(15, 10))
+    display.assign_to_figure_axis(fig, ax)
+    assert display.fig is not None
+    assert display.axes is not None
+
+
 @pytest.mark.mpl_image_compare(tolerance=30)
 def test_multidataset_plot_tuple():
     obj = arm.read_netcdf(sample_files.EXAMPLE_MET1)
@@ -105,6 +159,9 @@ def test_wind_rose():
     WindDisplay.plot('deg', 'wspd',
                      spd_bins=np.linspace(0, 20, 10), num_dirs=30,
                      tick_interval=2, cmap='viridis')
+    WindDisplay.set_thetarng(trng=(0., 360.))
+    WindDisplay.set_rrng((0., 14))
+
     sonde_ds.close()
     return WindDisplay.fig
 
@@ -206,7 +263,9 @@ def test_geoplot():
         sample_files.EXAMPLE_SONDE1)
     try:
         geodisplay = GeographicPlotDisplay({'sgpsondewnpnC1.b1': sonde_ds})
-        geodisplay.geoplot('tdry', marker='.')
+        geodisplay.geoplot('tdry', marker='.', cartopy_feature=['STATES', 'LAND', 'OCEAN', 'COASTLINE',
+                                                                'BORDERS', 'LAKES', 'RIVERS'],
+                           text={'Ponca City': [-97.0725, 36.7125]})
         return geodisplay.fig
     except Exception:
         pass
@@ -251,6 +310,20 @@ def test_stacked_bar_graph():
     return histdisplay.fig
 
 
+@pytest.mark.mpl_image_compare(tolerance=30)
+def test_stacked_bar_graph2():
+    sonde_ds = arm.read_netcdf(
+        sample_files.EXAMPLE_SONDE1)
+
+    histdisplay = HistogramDisplay({'sgpsondewnpnC1.b1': sonde_ds})
+    histdisplay.plot_stacked_bar_graph('tdry')
+    histdisplay.set_yrng([0, 400])
+    histdisplay.set_xrng([-70, 0])
+    sonde_ds.close()
+
+    return histdisplay.fig
+
+
 @pytest.mark.mpl_image_compare(tolerance=30)
 def test_stacked_bar_graph_sorted():
     sonde_ds = arm.read_netcdf(
@@ -318,7 +391,7 @@ def test_contour():
 
 
 @pytest.mark.mpl_image_compare(tolerance=30)
-def test_contourf():
+def test_contour2():
     files = glob.glob(sample_files.EXAMPLE_MET_CONTOUR)
     time = '2019-05-08T04:00:00.000000000'
     data = {}
@@ -332,6 +405,31 @@ def test_contourf():
         wind_fields.update({f: ['lon', 'lat', 'wspd_vec_mean', 'wdir_vec_mean']})
         station_fields.update({f: ['lon', 'lat', 'atmos_pressure']})
 
+    display = ContourDisplay(data, figsize=(8, 8))
+    display.create_contour(fields=fields, time=time, levels=50,
+                           contour='contour', cmap='viridis')
+    display.plot_vectors_from_spd_dir(fields=wind_fields, time=time, mesh=False, grid_delta=(0.1, 0.1))
+    display.plot_station(fields=station_fields, time=time, markersize=7, color='pink')
+
+    return display.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=30)
+def test_contourf():
+    files = glob.glob(sample_files.EXAMPLE_MET_CONTOUR)
+    time = '2019-05-08T04:00:00.000000000'
+    data = {}
+    fields = {}
+    wind_fields = {}
+    station_fields = {}
+    for f in files:
+        obj = arm.read_netcdf(f)
+        data.update({f: obj})
+        fields.update({f: ['lon', 'lat', 'temp_mean']})
+        wind_fields.update({f: ['lon', 'lat', 'wspd_vec_mean', 'wdir_vec_mean']})
+        station_fields.update({f: ['lon', 'lat', 'atmos_pressure', 'temp_mean', 'rh_mean',
+                                   'vapor_pressure_mean', 'temp_std']})
+
     display = ContourDisplay(data, figsize=(8, 8))
     display.create_contour(fields=fields, time=time, levels=50,
                            contour='contourf', cmap='viridis')
@@ -341,6 +439,31 @@ def test_contourf():
     return display.fig
 
 
+@pytest.mark.mpl_image_compare(tolerance=30)
+def test_contourf2():
+    files = glob.glob(sample_files.EXAMPLE_MET_CONTOUR)
+    time = '2019-05-08T04:00:00.000000000'
+    data = {}
+    fields = {}
+    wind_fields = {}
+    station_fields = {}
+    for f in files:
+        obj = arm.read_netcdf(f)
+        data.update({f: obj})
+        fields.update({f: ['lon', 'lat', 'temp_mean']})
+        wind_fields.update({f: ['lon', 'lat', 'wspd_vec_mean', 'wdir_vec_mean']})
+        station_fields.update({f: ['lon', 'lat', 'atmos_pressure', 'temp_mean', 'rh_mean',
+                                   'vapor_pressure_mean', 'temp_std']})
+
+    display = ContourDisplay(data, figsize=(8, 8))
+    display.create_contour(fields=fields, time=time, levels=50,
+                           contour='contourf', cmap='viridis')
+    display.plot_vectors_from_spd_dir(fields=wind_fields, time=time, mesh=False, grid_delta=(0.1, 0.1))
+    display.plot_station(fields=station_fields, time=time, markersize=7, color='pink')
+
+    return display.fig
+
+
 # Due to issues with pytest-mpl, for now we just test to see if it runs
 def test_time_height_scatter():
     sonde_ds = arm.read_netcdf(
@@ -370,7 +493,12 @@ def test_qc_bar_plot():
                                 subplot_shape=(2, ), figsize=(7, 4))
     display.plot(var_name, subplot_index=(0, ), assessment_overplot=True)
     display.day_night_background('sgpmetE13.b1', subplot_index=(0, ))
-    display.qc_flag_block_plot(var_name, subplot_index=(1, ))
+    color_lookup = {'Bad': 'red', 'Incorrect': 'red',
+                    'Indeterminate': 'orange', 'Suspect': 'orange',
+                    'Missing': 'darkgray', 'Not Failing': 'green',
+                    'Acceptable': 'green'}
+    display.qc_flag_block_plot(var_name, subplot_index=(1, ),
+                               assessment_color=color_lookup)
 
     ds_object.close()
 
@@ -463,3 +591,45 @@ def test_assessment_overplot_multi():
 
     ds.close()
     return display.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=30)
+def test_plot_barbs_from_u_v():
+    sonde_ds = arm.read_netcdf(
+        sample_files.EXAMPLE_TWP_SONDE_WILDCARD)
+    BarbDisplay = TimeSeriesDisplay({'sonde_darwin': sonde_ds})
+    BarbDisplay.plot_barbs_from_u_v('u_wind', 'v_wind', 'pres',
+                                    num_barbs_x=20)
+    sonde_ds.close()
+    return BarbDisplay.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=30)
+def test_plot_barbs_from_u_v2():
+    bins = list(np.linspace(0, 1, 10))
+    xbins = list(pd.date_range(pd.to_datetime('2020-01-01'),
+                               pd.to_datetime('2020-01-02'), 12))
+    y_data = np.full([len(xbins), len(bins)], 1.)
+    x_data = np.full([len(xbins), len(bins)], 2.)
+    y_array = xr.DataArray(y_data, dims={'xbins': xbins, 'ybins': bins},
+                           attrs={'units': 'm/s'})
+    x_array = xr.DataArray(x_data, dims={'xbins': xbins, 'ybins': bins},
+                           attrs={'units': 'm/s'})
+    xbins = xr.DataArray(xbins, dims={'xbins': xbins})
+    ybins = xr.DataArray(bins, dims={'ybins': bins})
+    fake_obj = xr.Dataset({'xbins': xbins, 'ybins': ybins,
+                          'ydata': y_array, 'xdata': x_array})
+    BarbDisplay = TimeSeriesDisplay(fake_obj)
+    BarbDisplay.plot_barbs_from_u_v('xdata', 'ydata', None, num_barbs_x=20,
+                                    num_barbs_y=20, set_title='test plot', cmap='jet')
+    fake_obj.close()
+    return BarbDisplay.fig
+
+
+@pytest.mark.mpl_image_compare(tolerance=30)
+def test_2D_timeseries_plot():
+    obj = arm.read_netcdf(sample_files.EXAMPLE_CEIL1)
+    display = TimeSeriesDisplay(obj)
+    display.plot('backscatter', y_rng=[0, 5000], use_var_for_y='range')
+    matplotlib.pyplot.show()
+    return display.fig
